Database Documentation
=======================

Database relationship diagram
------------------------------


.. figure:: ./diagrams/db-relationship-diagram.svg
    :target: /_images/db-relationship-diagram.svg

    Current database relationship diagram
